# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2019-12-13 21:21:28 UTC
import datetime

version = "4.0"
githash = "d5f5a76fe87beca9a132186824c02408cf827ab8"


major = 4
minor = 0
bugfix = 0

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 12, 13, 21, 21, 28)
debug = False

astropy_helpers_version = ""
